==> dde-launchpad_0.4.6.tar.xz: BUILD/translations/dde-launchpad_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="30"/>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="40"/>
        <source>Pin to Top</source>
        <translation>移到頂部</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Remove from favorites</source>
        <translation>從收藏中移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Add to favorites</source>
        <translation>添加到收藏</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Send to desktop</source>
        <translation>建立桌面捷徑</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Remove from desktop</source>
        <translation>移除桌面捷徑</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Remove from dock</source>
        <translation>移除任務欄捷徑</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Send to dock</source>
        <translation>釘選到任務欄</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Add to startup</source>
        <translation>開機啟動</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Remove from startup</source>
        <translation>取消開機啟動</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="89"/>
        <source>Use a proxy</source>
        <translation>使用代理伺服器</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="95"/>
        <source>Disable display scaling</source>
        <translation>停用畫面縮放</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="102"/>
        <source>Uninstall</source>
        <translation>解除安裝</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">網路</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">聊天</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">音樂</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">影片</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">圖形</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">辦公</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">閱讀</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">開發</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系統</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="19"/>
        <source>Internet</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Video</source>
        <translation>影片</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Graphics</source>
        <translation>圖形</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Office</source>
        <translation>辦公</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Reading</source>
        <translation>閱讀</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Development</source>
        <translation>開發</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>System</source>
        <translation>系統</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="270"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="282"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="296"/>
        <source>Confirm</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="346"/>
        <location filename="../qml/WindowedFrame.qml" line="230"/>
        <source>No search results</source>
        <translation>無搜尋結果</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation type="vanished">應用分類</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="103"/>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">設定</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="361"/>
        <location filename="../qml/WindowedFrame.qml" line="266"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="115"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="157"/>
        <source>My Favorites</source>
        <translation>收藏應用</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="191"/>
        <source>Add your favorite apps here</source>
        <translation>添加應用到收藏</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="202"/>
        <source>All Apps</source>
        <translation>所有應用</translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.6.12.tar.xz: BUILD/translations/dde-launchpad_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">無搜尋結果</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="31"/>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="41"/>
        <source>Pin to Top</source>
        <translation>移到頂部</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Remove from favorites</source>
        <translation>從收藏中移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Add to favorites</source>
        <translation>添加到收藏</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Send to desktop</source>
        <translation>建立桌面捷徑</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Remove from desktop</source>
        <translation>移除桌面捷徑</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Remove from dock</source>
        <translation>移除任務欄捷徑</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Send to dock</source>
        <translation>釘選到任務欄</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Add to startup</source>
        <translation>開機啟動</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Remove from startup</source>
        <translation>取消開機啟動</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="92"/>
        <source>Use a proxy</source>
        <translation>使用代理伺服器</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="100"/>
        <source>Disable display scaling</source>
        <translation>停用畫面縮放</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="107"/>
        <source>Uninstall</source>
        <translation>解除安裝</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">網路</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">聊天</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">音樂</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">影片</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">圖形</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">辦公</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">閱讀</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">開發</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系統</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="26"/>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="40"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>Frequently Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>All Apps</source>
        <translation type="unfinished">所有應用</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Internet</source>
        <translation>網路</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Video</source>
        <translation>影片</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Graphics</source>
        <translation>圖形</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Office</source>
        <translation>辦公</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Reading</source>
        <translation>閱讀</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>Development</source>
        <translation>開發</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>System</source>
        <translation>系統</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="41"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="313"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="325"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="339"/>
        <source>Confirm</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="27"/>
        <source>Recently Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="26"/>
        <source>All Apps</source>
        <translation type="unfinished">所有應用</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="76"/>
        <source>No search results</source>
        <translation type="unfinished">無搜尋結果</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="39"/>
        <source>Free sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="52"/>
        <source>Sort by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="64"/>
        <source>Sort by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="124"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="139"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="154"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="169"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="184"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">無搜尋結果</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation type="vanished">應用分類</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">電源</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">設定</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜尋</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">收藏應用</translation>
    </message>
    <message>
        <source>Add your favorite apps here</source>
        <translation type="vanished">添加應用到收藏</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">所有應用</translation>
    </message>
</context>
</TS>
